==> youqian-center-api-0.0.1-beta2-1-20200119.012803-2-sources.jar: cn/com/duiba/youqian/center/api/remoteservice/RemoteOrderService.java <==
package cn.com.duiba.youqian.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.youqian.center.api.entity.SignEntity;
import cn.com.duiba.youqian.center.api.request.order.*;
import cn.com.duiba.youqian.center.api.result.PageResult;
import cn.com.duiba.youqian.center.api.result.order.OrderContractVO;
import cn.com.duiba.youqian.center.api.result.order.OrderDescVO;
import cn.com.duiba.youqian.center.api.result.order.OrderListVO;
import cn.com.duiba.youqian.center.api.result.order.OrderSignVO;
import cn.com.duiba.youqian.center.api.result.user.UserVO;

import java.util.List;

/**
 * @author tengtuox
 * @date 2020/1/3
 * @description
 */
@AdvancedFeignClient
public interface RemoteOrderService {
    /**
     * 创建订单并返回订单编号
     * @param userId 卖家的id
     * @param orderInfoRequest 订单商户的基本信息
     * @return
     */
    OrderContractVO create(Long userId, OrderInfoRequest orderInfoRequest) throws BizException;

    /**
     * 更新订单
     * @param userId 登陆人的ID
     * @param orderRequest 买家的信息
     * @return
     */
    void updateOrder(Long userId, AddOrderRequest orderRequest) throws BizException;

    /**
     * 查询订单的详情
     * @param userId 用户id
     * @param orderNo 订单编号
     * @return
     * @throws BizException
     */
    OrderDescVO getOrderDescById(Long userId, String orderNo) throws BizException;

    /**
     * 查询卖家对应的买家及信息
     * @param userId 卖家登录ID
     * @return
     */
    List<UserVO> getRelevanceUser(Long userId);

    /**
     * 首页-签约统计
     * @param userId 当前登录的用户
     * @return
     */
    OrderSignVO countSign(Long userId);

    /**
     * 获得协议模板
     */
    String getContractTemplate(Long userId,ContractInfoVO contractInfoVO);

    /**
     * 返回首页的订单列表
     * @param orderRequest
     * @return
     */
    PageResult<OrderListVO> list(OrderRequest orderRequest);

    /**
     * 处理订单合同
     * @param account 上上签唯一的标识
     * @param contractId 合同ID
     * @param orderNo 订单编号
     * @param signerStatus 签署状态
     */
    void handleOrderContract(String account, String contractId,String orderNo, String signerStatus) throws BizException;

    /**
     * 获取卖家的签约主体
     * @param
     */
    List<SignEntity> getShellSignEntity(Long userId);
}

==> youqian-center-api-0.0.12-beta2-20200117.072318-1-sources.jar: cn/com/duiba/youqian/center/api/remoteservice/RemoteOrderService.java <==
package cn.com.duiba.youqian.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.youqian.center.api.entity.SignEntity;
import cn.com.duiba.youqian.center.api.request.order.ContractInfoVO;
import cn.com.duiba.youqian.center.api.request.order.GoodsReq;
import cn.com.duiba.youqian.center.api.request.order.OrderInfoRequest;
import cn.com.duiba.youqian.center.api.request.order.OrderRequest;
import cn.com.duiba.youqian.center.api.result.PageResult;
import cn.com.duiba.youqian.center.api.result.order.OrderContractVO;
import cn.com.duiba.youqian.center.api.result.order.OrderDescVO;
import cn.com.duiba.youqian.center.api.result.order.OrderListVO;
import cn.com.duiba.youqian.center.api.result.order.OrderSignVO;
import cn.com.duiba.youqian.center.api.result.user.UserVO;

import java.util.List;

/**
 * @author tengtuox
 * @date 2020/1/3
 * @description
 */
@AdvancedFeignClient
public interface RemoteOrderService {
    /**
     * 创建订单并返回订单编号
     * @param userId 卖家的id
     * @param orderInfoRequest 订单商户的基本信息
     * @return
     */
    OrderContractVO create(Long userId, OrderInfoRequest orderInfoRequest) throws BizException;

    /**
     * 更新订单
     * @param userId 登陆人的ID
     * @param mobile 买家手机号
     * @param name 买家姓名
     * @param orderNo 当前订单编号
     * @param company 买家的公司名字
     * @param receiveAddress 买家收货地址
     * @return
     */
    void updateOrder(Long userId, String mobile, String name,String orderNo,String company,String receiveAddress) throws BizException;

    /**
     * 查询订单的详情
     * @param userId 用户id
     * @param orderNo 订单编号
     * @return
     * @throws BizException
     */
    OrderDescVO getOrderDescById(Long userId, String orderNo) throws BizException;

    /**
     * 查询卖家对应的买家及信息
     * @param userId 卖家登录ID
     * @return
     */
    List<UserVO> getRelevanceUser(Long userId);

    /**
     * 首页-签约统计
     * @param userId 当前登录的用户
     * @return
     */
    OrderSignVO countSign(Long userId);

    /**
     * 获得协议模板
     */
    String getContractTemplate(Long userId,ContractInfoVO contractInfoVO);

    /**
     * 返回首页的订单列表
     * @param orderRequest
     * @return
     */
    PageResult<OrderListVO> list(OrderRequest orderRequest);

    /**
     * 处理订单合同
     * @param account 上上签唯一的标识
     * @param contractId 合同ID
     * @param orderNo 订单编号
     * @param signerStatus 签署状态
     */
    void handleOrderContract(String account, String contractId,String orderNo, String signerStatus) throws BizException;

    /**
     * 获取卖家的签约主体
     * @param
     */
    List<SignEntity> getShellSignEntity(Long userId);
}
